.. _component-stepsize-adaptation:

ComponentStepsizeAdaptation
=============================

.. inheritance-diagram:: gmmvi.optimization.gmmvi_modules.component_stepsize_adaptation.ComponentStepsizeAdaptation gmmvi.optimization.gmmvi_modules.component_stepsize_adaptation.FixedComponentStepsizeAdaptation gmmvi.optimization.gmmvi_modules.component_stepsize_adaptation.DecayingComponentStepsizeAdaptation gmmvi.optimization.gmmvi_modules.component_stepsize_adaptation.ImprovementBasedComponentStepsizeAdaptation
    :parts: -4

.. autoclass:: gmmvi.optimization.gmmvi_modules.component_stepsize_adaptation.ComponentStepsizeAdaptation
   :members:
   :undoc-members:

.. _decaying-comp:

DecayingComponentStepsizeAdaptation
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. autoclass:: gmmvi.optimization.gmmvi_modules.component_stepsize_adaptation.DecayingComponentStepsizeAdaptation
   :members:
   :undoc-members:

.. _fixed-comp:

FixedComponentStepsizeAdaptation
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. autoclass:: gmmvi.optimization.gmmvi_modules.component_stepsize_adaptation.FixedComponentStepsizeAdaptation
   :members:
   :undoc-members:

.. _adaptive-comp:

ImprovementBasedComponentStepsizeAdaptation
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. autoclass:: gmmvi.optimization.gmmvi_modules.component_stepsize_adaptation.ImprovementBasedComponentStepsizeAdaptation
   :members:
   :undoc-members:

.. toctree::
   :maxdepth: 2
   :glob: